<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package roofers
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function roofers_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}
    
    $classes[] = 'roofer_body';

	return $classes;
}
add_filter( 'body_class', 'roofers_body_classes' );

function roofers_post_classes( $classes ) {
    
	if ( has_post_format('image') ) {
		$classes[] = 'image-post';
	}

    if ( false == get_post_format() ) {
		$classes[] = 'standard-post';
	}

	return $classes;
}
add_filter( 'post_class', 'roofers_post_classes' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function roofers_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', bloginfo( 'pingback_url' ), '">';
	}
}
add_action( 'wp_head', 'roofers_pingback_header' );

if ( ! function_exists( 'roofers_breadcrumbs' ) ) {
	function roofers_breadcrumbs( $args = array() ) {
		if ( is_front_page() ) {
			return;
		}
		if ( get_theme_mod( 'roofers_show_breadcrumbs_setting' ) == 'no' ) {
			return;
		}
		global $post;
		$defaults  = array(
			'separator_icon'      => '&#47;',
			'breadcrumbs_id'      => 'breadcrumbs',
			'breadcrumbs_classes' => 'breadcrumb-trail breadcrumb',
			'home_title'          => 'Home'
		);
		$args      = apply_filters( 'roofers_breadcrumbs_args', wp_parse_args( $args, $defaults ) );
		$separator = '<li class="seprator">' . esc_attr( $args['separator_icon'] ) . '</li>' ;
		/***** Begin Markup *****/
		// Open the breadcrumbs
		$html = '<ul id="' . esc_attr( $args['breadcrumbs_id'] ) . '" class="' . esc_attr( $args['breadcrumbs_classes'] ) . '">';
		// Add Homepage link & separator (always present)
		$html .= '<li class="lnk_pag link-home"><a class="bread-link bread-home" href="' . get_home_url() . '" title="' . esc_attr( $args['home_title'] ) . '">' . esc_attr( $args['home_title'] ) . '</a></li>';
		$html .= $separator;
		// Post
		if ( is_singular( 'post' ) ) {
			$category = get_the_category();
			$category_values = array_values( $category );
			$last_category = end( $category_values );
			$cat_parents = rtrim( get_category_parents( $last_category->term_id, true, ',' ), ',' );
			$cat_parents = explode( ',', $cat_parents );
			foreach ( $cat_parents as $parent ) {
				$html .= '<li class="lnk_pag post-cat">' . wp_kses( $parent, wp_kses_allowed_html( 'a' ) ) . '</li>';
				$html .= $separator;
			}
			$html .= '<li class="lnk_pag item-current item-' . $post->ID . '">' . get_the_title() . '</li>';
		} elseif ( is_singular( 'page' ) ) {
			if ( $post->post_parent ) {
				$parents = get_post_ancestors( $post->ID );
				$parents = array_reverse( $parents );
				foreach ( $parents as $parent ) {
					$html .= '<li class="lnk_pag item-parent item-parent-' . esc_attr( $parent ) . '"><a class="bread-parent bread-parent-' . esc_attr( $parent ) . '" href="' . esc_url( get_permalink( $parent ) ) . '" title="' . get_the_title( $parent ) . '">' . get_the_title( $parent ) . '</a></li>';
					$html .= $separator;
				}
			}
			$html .= '<li class="lnk_pag item-current item-' . $post->ID . '"> ' . get_the_title() . '</li>';
		} elseif ( is_singular( 'attachment' ) ) {
			$parent_id        = $post->post_parent;
			$parent_title     = get_the_title( $parent_id );
			$parent_permalink = esc_url( get_permalink( $parent_id ) );
			$html .= '<li class="lnk_pag item-parent"><a class="bread-parent" href="' . esc_url( $parent_permalink ) . '">' . esc_attr( $parent_title ) . '</a></li>';
			$html .= $separator;
			$html .= '<li class="lnk_pag item-current item-' . $post->ID . '"> ' . get_the_title() . '</li>';
		} elseif ( is_singular() ) {
			$post_type         = get_post_type();
			$post_type_object  = get_post_type_object( $post_type );
			$post_type_archive = get_post_type_archive_link( $post_type );
			$html .= '<li class="lnk_pag item-cat item-custom-post-type-' . esc_attr( $post_type ) . '"><a class="bread-cat bread-custom-post-type-' . esc_attr( $post_type ) . '" href="' . esc_url( $post_type_archive ) . '" title="' . esc_attr( $post_type_object->labels->name ) . '">' . esc_attr( $post_type_object->labels->name ) . '</a></li>';
			$html .= $separator;
			$html .= '<li class="lnk_pag item-current item-' . $post->ID . '">' . $post->post_title . '</li>';
		} elseif ( is_category() ) {
			$parent = get_queried_object()->category_parent;
			if ( $parent !== 0 ) {
				$parent_category = get_category( $parent );
				$category_link   = get_category_link( $parent );
				$html .= '<li class="lnk_pag item-parent item-parent-' . esc_attr( $parent_category->slug ) . '"><a class="bread-parent bread-parent-' . esc_attr( $parent_category->slug ) . '" href="' . esc_url( $category_link ) . '" title="' . esc_attr( $parent_category->name ) . '">' . esc_attr( $parent_category->name ) . '</a></li>';
				$html .= $separator;
			}
			$html .= '<li class="lnk_pag item-current item-cat"><li class="bread-current bread-cat" title="' . $post->ID . '">' . single_cat_title( '', false ) . '</li></li>';
		} elseif ( is_tag() ) {
			$html .= '<li class="lnk_pag item-current item-tag"><li class="bread-current bread-tag">' . single_tag_title( '', false ) . '</li></li>';
		} elseif ( is_author() ) {
			$html .= '<li class="lnk_pag item-current item-author"><li class="bread-current bread-author">' . get_queried_object()->display_name . '</li></li>';
		} elseif ( is_day() ) {
			$html .= '<li class="lnk_pag item-current item-day"><li class="bread-current bread-day">' . get_the_date() . '</li></li>';
		} elseif ( is_month() ) {
			$html .= '<li class="lnk_pag item-current item-month"><li class="bread-current bread-month">' . get_the_date( 'F Y' ) . '</li></li>';
		} elseif ( is_year() ) {
			$html .= '<li class="lnk_pag item-current item-year"><li class="bread-current bread-year">' . get_the_date( 'Y' ) . '</li></li>';
		} elseif ( is_archive() ) {
			$custom_tax_name = get_queried_object()->name;
			$html .= '<li class="lnk_pag item-current item-archive"><li class="bread-current bread-archive">' . esc_attr( $custom_tax_name ) . '</li></li>';
		} elseif ( is_search() ) {
			$html .= '<li class="lnk_pag item-current item-search"><li class="bread-current bread-search">Search results for: ' . get_search_query() . '</li></li>';
		} elseif ( is_404() ) {
			$html .= '<li class="lnk_pag">' . __( 'Error 404', 'roofers' ) . '</li>';
		} elseif ( is_home() ) {
			$html .= '<li class="lnk_pag">' . get_the_title( get_option( 'page_for_posts' ) ) . '</li>';
		}
		$html .= '</ul>';
		$html = apply_filters( 'roofers_breadcrumbs_filter', $html );
		echo wp_kses_post( $html );
	}
}
